========================
Pages d'aide de Telemeta
========================

Pour obtenir un accès spécifique à l'ensemble des archives du CREM hébergé sur ce site, merci de contacter :

    Aude Julien <aude.da-cruz-lima (at) mae.u-paris10.fr>

Pour obtenir une aide technique, merci de vous inscrire à la mailing liste de Telemeta :

    `http://lists.parisson.com/cgi-bin/mailman/listinfo/telemeta <http://lists.parisson.com/cgi-bin/mailman/listinfo/telemeta>`_

ou bien contacter la hotline parisson par e-mail :

    support@parisson.com

ou twitter :

    `http://twitter.com/telemeta <http://twitter.com/telemeta>`_

Pour plus d'informations sur le système Telemeta, voir `telemeta.org <http://telemeta.org>`_

Telemeta utilise la librairie audio TimeSide : `code.google.com/p/timeside/ <http://code.google.com/p/timeside/>`_